package com.lantone.qc.kernel.catalogue.behospitalized;

import com.alibaba.fastjson.JSONArray;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.ChiefPresentSimilarityServiceClient;
import com.lantone.qc.kernel.structure.ai.ModelAI;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.entity.GeneralDesc;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.model.label.PresentLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName : BEH0011
 * @Description : 初步诊断不完整
 * 原逻辑 --初步诊断没有既往史里的慢性疾病
 * 现逻辑 --检查现病史中一般情况之后的疾病名称，既往史中的疾病名称是否都在初步诊断里
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class BEH0011 extends QCCatalogue {
    //    @Autowired
    //    private SpecialStorageUtil specialStorageUtil;
    @Autowired
    ChiefPresentSimilarityServiceClient chiefPresentSimilarityServiceClient;

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        PresentLabel presentLabel = inputInfo.getBeHospitalizedDoc().getPresentLabel();
        DiagLabel initialDiagLabel = inputInfo.getBeHospitalizedDoc().getInitialDiagLabel();
        PastLabel pastLabel = inputInfo.getBeHospitalizedDoc().getPastLabel();
        if (initialDiagLabel == null) {
            status.set("0");
            return;
        }
        List<String> presentPastDiags = new ArrayList<>();
        if (presentLabel != null) {
            List<GeneralDesc> generals = presentLabel.getGenerals();
            if (generals.size() > 0) {
                String presentText = presentLabel.getText();
                List<Diag> presentDiags = presentLabel.getDiags();
                /* 取现病史中一般情况之后的疾病名称 */
                if (StringUtil.isNotBlank(presentText) && presentDiags.size() > 0) {
                    String lastGeneral = generals.get(generals.size() - 1).getName();
                    int lastGeneralIndex = presentText.indexOf(lastGeneral);
                    for (Diag presentDiag : presentDiags) {
                        if (presentDiag.getNegative() != null) {
                            continue;
                        }
                        /* 现病史中一般情况之后的疾病名称 */
                        if (presentText.indexOf(presentDiag.getHospitalDiagName()) > lastGeneralIndex) {
                            presentPastDiags.add(presentDiag.getHospitalDiagName());
                        }
                    }
                }
            }
        }
        /* 取既往史中疾病名称 */
        if (pastLabel != null) {
            List<Diag> pastDiags = pastLabel.getDiags();
            addDiagHospitalName(presentPastDiags, pastDiags);
        }
        /* 取初步诊断中疾病名称 */
        List<String> initDiags = new ArrayList<>();
        List<Diag> initialDiagDiags = initialDiagLabel.getDiags();
        addDiagHospitalName(initDiags, initialDiagDiags);

        int matchSum = 0;
        ModelAI modelAI = new ModelAI();
        for (String presentPastDiag : presentPastDiags) {
            JSONArray jsonArray = modelAI.loadChiefPresentSimilarAI(presentPastDiag, initDiags, false
                    , "diagnose", chiefPresentSimilarityServiceClient);
            if (jsonArray.size() == 2) {
                /* 相似度最高症状 */
                String symptom = jsonArray.getString(0);
                /* 相似度分数 */
                double likeRate = jsonArray.getDoubleValue(1);
                if (likeRate > 0.9) {
                    matchSum++;
                }
            }
        }
        if (matchSum == presentPastDiags.size()){
            status.set("0");
        }
        /*
        if (initDiags.containsAll(presentPastDiags)) {
            status.set("0");
        }
         */
    }

    private void addDiagHospitalName(List<String> presentPastDiag, List<Diag> pastDiags) {
        for (Diag pastDiag : pastDiags) {
            if (pastDiag.getNegative() != null) {
                continue;
            }
            presentPastDiag.add(pastDiag.getHospitalDiagName());
        }
    }
    /* 原逻辑
    Map<String, Map<String, Object>> diagMap = specialStorageUtil.getJsonStringValue(KernelConstants.CONCEPT_DIAG_PROPERTY_MAP);
    String initDiagText = CatalogueUtil.removeSpecialChar(initialDiagLabel.getText());
        if (pastLabel.getDiags() != null) {
            List<Diag> diags = pastLabel.getDiags().stream().filter(diag -> diag.getNegative() == null).collect(Collectors.toList());
            List<String> initDiags = Arrays.asList(initDiagText.split(","));
            if (diags.size() > 0) {
                for (Diag diag : diags) {
                    Map<String, Object> map = (Map<String, Object>) diagMap.get(diag.getName());
                    if (map != null && map.size() > 0) {
                        String chronic = (String) map.get("chronic");//1是慢病
                        if ("1".equals(chronic) && !initDiags.contains(diag.getName())) {
                            if (StringUtils.isEmpty(info.get())) {
                                info.set(diag.getName());
                            } else {
                                info.set(info.get() + "," + diag.getName());
                            }
                        }
                    }
                }
            }
        }
        if (StringUtils.isEmpty(info.get())) {
            status.set("0");
        }
     */
}