package com.lantone.qc.kernel.catalogue.behospitalized;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.General;
import com.lantone.qc.pub.model.entity.GeneralDesc;
import com.lantone.qc.pub.model.label.PresentLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * @ClassName : BEH0441
 * @Description :  现病史缺少发病以来食欲描述
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class BEH0441 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        if (inputInfo.getBeHospitalizedDoc() == null) {
            status.set("0");
            return;
        }
        PresentLabel presentLabel = inputInfo.getBeHospitalizedDoc().getPresentLabel();
        if (presentLabel == null) {
            status.set("0");
            return;
        }
        String presentText = presentLabel.getText();
        if (StringUtil.isNotBlank(presentText)) {
            List<String> words = Lists.newArrayList("胃纳", "食纳", "食欲", "未纳", "纳眠", "饮食", "纳眠"
                    ,"禁食","未食","鼻饲","食","吃","饮");
            for (String word : words) {
                if (presentText.contains(word)) {
                    status.set("0");
                    return;
                }
            }
        }
        List<GeneralDesc> generals = presentLabel.getGenerals();
        List<General> gens = presentLabel.getGens();

        if (ListUtil.isEmpty(generals) && ListUtil.isEmpty(gens)) {
            status.set("0");
            return;
        }

        if (ListUtil.isNotEmpty(generals)) {
            for (GeneralDesc general : generals) {
                if (general.getName().contains("纳") || general.getName().contains("饮食")
                        || general.getName().contains("进食") || general.getName().contains("食欲")) {
                    status.set("0");
                    break;
                }
            }
        }

        if (ListUtil.isNotEmpty(gens)) {
            for (General general : gens) {
                if (general.getName().contains("纳") || general.getName().contains("饮食") || general.getName().contains("进食")) {
                    status.set("0");
                    break;
                }
            }
        }

    }
}